@@ -56,7 +56,7 @@ class CreateShardingDBInstanceRequest(RpcRequest):
 		self.add_query_param('NetworkType',NetworkType)
 
 	def get_ReplicaSets(self):
-		return self.get_query_params().get('ReplicaSets')
+		return self.get_query_params().get('ReplicaSet')
 
 	def set_ReplicaSets(self, ReplicaSets):
 		for depth1 in range(len(ReplicaSets)):
@@ -120,7 +120,7 @@ class CreateShardingDBInstanceRequest(RpcRequest):
 		self.add_query_param('OwnerAccount',OwnerAccount)
 
 	def get_ConfigServers(self):
-		return self.get_query_params().get('ConfigServers')
+		return self.get_query_params().get('ConfigServer')
 
 	def set_ConfigServers(self, ConfigServers):
 		for depth1 in range(len(ConfigServers)):
@@ -136,7 +136,7 @@ class CreateShardingDBInstanceRequest(RpcRequest):
 		self.add_query_param('OwnerId',OwnerId)
 
 	def get_Mongoss(self):
-		return self.get_query_params().get('Mongoss')
+		return self.get_query_params().get('Mongos')
 
 	def set_Mongoss(self, Mongoss):
 		for depth1 in range(len(Mongoss)):
